.. _sec-examples:

Examples
========

.. toctree::

    ../examples/ccg2discocat.ipynb
    ../examples/reader.ipynb
    ../examples/tree_reader.ipynb
    ../examples/rewrite.ipynb
    ../examples/circuit.ipynb
    ../examples/tensor.ipynb
    ../examples/classical_pipeline.ipynb
    ../examples/quantum_pipeline.ipynb
    ../examples/quantum_pipeline_jax.ipynb

